/*
 * Copyright 2022-2023 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package xyz.zhouxy.plusone.exception;

import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.ResponseStatus;

/**
 * 需要时，当数据操作的结果不符合预期时抛出的异常
 *
 * <p>
 * 暂时先这样，后续完善异常体系时可能会更改。
 *
 * @author <a href="https://gitee.com/zhouxy108">ZhouXY</a>
 * @see xyz.zhouxy.plusone.util.AssertResult
 */
@ResponseStatus(HttpStatus.INTERNAL_SERVER_ERROR)
public class DataOperationResultException extends SysException {

    @java.io.Serial
    private static final long serialVersionUID = -9220765735990318186L;

    public static final int ERROR_CODE = 4110200;

    public DataOperationResultException() {
        super(ERROR_CODE, "数据操作结果不符合预期");
    }

    public DataOperationResultException(String message) {
        super(ERROR_CODE, message);
    }
}
