/*
 * Copyright 2022-2023 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package xyz.zhouxy.plusone.util;

import xyz.zhouxy.plusone.exception.DataNotExistException;
import xyz.zhouxy.plusone.exception.DataOperationResultException;

import java.util.Objects;
import java.util.function.Supplier;

/**
 * 对数据库执行结果进行判断
 *
 * @author <a href="https://gitee.com/zhouxy108">ZhouXY</a>
 */
public final class AssertResult {

    private AssertResult() {
        throw new IllegalStateException("Utility class");
    }

    public static <E extends Throwable> void isTrue(boolean condition, Supplier<E> e) throws E {
        if (!condition) {
            throw e.get();
        }
    }

    public static <T> void equals(T result, T expectedValue) {
        isTrue(Objects.equals(result, expectedValue), DataOperationResultException::new);
    }

    public static <T> void equals(T result, T expectedValue, String msgTemplate, Object... args) {
        isTrue(!Objects.equals(result, expectedValue),
                () -> new DataOperationResultException(String.format(msgTemplate, args)));
    }

    public static void updateOneRow(int i) {
        equals(i, 1);
    }

    public static void updateOneRow(int i, String format, Object... args) {
        equals(i, 1, format, args);
    }

    public static void nonNull(Object obj) {
        isTrue(Objects.nonNull(obj), DataNotExistException::new);
    }

    public static void nonNull(Object obj, String message) {
        isTrue(Objects.nonNull(obj), () -> new DataNotExistException(message));
    }
}
