/*
 * Copyright 2022-2023 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package xyz.zhouxy.plusone.util;

import java.util.Objects;
import java.util.regex.Pattern;

import org.springframework.util.Assert;
import org.springframework.util.StringUtils;

/**
 * 字符串工具类
 *
 * @author <a href="https://gitee.com/zhouxy108">ZhouXY</a>
 */
public class PlusoneStrUtil {

    private PlusoneStrUtil() {
        throw new IllegalStateException("Utility class");
    }

    public static final String EMPTY_STR = "";

    public static String getTextOrEmpty(String value) {
        return StringUtils.hasText(value) ? value : EMPTY_STR;
    }

    public static String getStrOrEmpty(String value) {
        return StringUtils.hasLength(value) ? value : EMPTY_STR;
    }

    public static String checkString(String value, String regex, String message) {
        Assert.notNull(value, message);
        Assert.isTrue(Pattern.matches(regex, value), message);
        return value;
    }

    public static String checkStringNullable(String value, String regex, String message) {
        return Objects.nonNull(value) ? checkString(value, regex, message) : null;
    }

    public static String checkStringOrDefault(String value, String regex, String message) {
        return StringUtils.hasText(value) ? checkString(value, regex, message) : "";
    }
}
