/*
 * Copyright 2022-2023 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package xyz.zhouxy.plusone.domain;

import java.util.UUID;

import lombok.Getter;

/**
 * 领域事件
 *
 * <p>
 * <b>根据所使用的消息机制的不同，可能需要继承其它类，或实现 {@link java.io.Serializable} 接口</b>
 * </p>
 *
 * @author <a href="https://gitee.com/zhouxy108">ZhouXY</a>
 * @see Entity
 * @see IEventHandler
 */
@Getter
public abstract class DomainEvent {
    private String identifier;
    private long happenedAt;

    protected DomainEvent() {
        this.identifier = UUID.randomUUID().toString();
        this.happenedAt = System.currentTimeMillis();
    }
}
