/*
 * Copyright 2022-2023 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package xyz.zhouxy.plusone.domain;

import java.io.Serializable;
import java.util.Optional;

/**
 * Repository 基础接口
 *
 * @author <a href="https://gitee.com/zhouxy108">ZhouXY</a>
 * @see AggregateRoot
 */
public interface IRepository<T extends AggregateRoot<ID>, ID extends Serializable> {

    Optional<T> find(ID id);

    T save(T entity);

    void delete(T entity);

    boolean exists(ID id);

}
