/*
 * Copyright 2022-2023 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package xyz.zhouxy.plusone.domain;

import java.util.Comparator;
import java.util.Objects;

/**
 * 带 orderNumber 字段，可用来排序
 *
 * @author <a href="https://gitee.com/zhouxy108">ZhouXY</a>
 */
public interface IWithOrderNumber extends Comparable<IWithOrderNumber> {

    int getOrderNumber();

    @Override
    default int compareTo(IWithOrderNumber that) {
        return new OrderNumberComparator<IWithOrderNumber>().compare(this, that);
    }

    class OrderNumberComparator<T extends Comparable<T>>
            implements Comparator<IWithOrderNumber> {
        @Override
        public int compare(IWithOrderNumber a, IWithOrderNumber b) {
            if (Objects.equals(a, b)) {
                return 0;
            }
            if (a == null) {
                return -1;
            }
            return (b == null) ? 1 : Integer.compare(a.getOrderNumber(), b.getOrderNumber());
        }
    }
}
