/*
 * Copyright 2022-2023 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package xyz.zhouxy.plusone.domain;

import java.util.Optional;
import java.util.regex.Pattern;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonValue;

/**
 * 带校验的字符串值对象
 *
 * @author <a href="https://gitee.com/zhouxy108">ZhouXY</a>
 */
public abstract class ValidatableStringRecord implements IValueObject {

    protected String value;
    protected final Pattern format;

    protected ValidatableStringRecord(Pattern format) {
        this.format = format;
    }

    @JsonIgnore
    protected boolean isValid() {
        return format.matcher(value).matches();
    }

    @JsonValue
    public String value() {
        return value;
    }

    @Override
    public String toString() {
        return value;
    }

    public static String getValueOrNull(Optional<? extends ValidatableStringRecord> s) {
        return s.isPresent() ? s.get().value() : null;
    }
}
