/*
 * Copyright 2022-2023 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package xyz.zhouxy.plusone.infrastructure.pojo;

import java.time.LocalDateTime;

import lombok.Getter;
import lombok.Setter;
import lombok.ToString;

/**
 * 实体的持久化对象
 *
 * <p>
 * <i>由于本项目目前是手动实现 Repository，直接将实体持久化，
 * 查询结果也是直接实例化为 Entity，故暂时不使用 PO。</i>
 * </p>
 *
 * @author <a href="https://gitee.com/zhouxy108">ZhouXY</a>
 */
@Getter
@Setter
@ToString
public abstract class AbstractEntityPO {
    protected Long createdBy;
    protected LocalDateTime createTime;
    protected Long updatedBy;
    protected LocalDateTime updateTime;

    public abstract Long getId();

    public void auditFields(Long updatedBy, LocalDateTime updateTime) {
        this.updatedBy = updatedBy;
        this.updateTime = updateTime;
    }

    public void auditFields(Long createdBy, LocalDateTime createTime, Long updatedBy, LocalDateTime updateTime) {
        this.createdBy = createdBy;
        this.createTime = createTime;
        this.updatedBy = updatedBy;
        this.updateTime = updateTime;
    }
}
