/*
 * Copyright 2022-2023 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package xyz.zhouxy.plusone.jdbc;

import org.springframework.jdbc.core.namedparam.BeanPropertySqlParameterSource;
import org.springframework.lang.Nullable;

/**
 * 扩展了 {@link BeanPropertySqlParameterSource}，在将 POJO 转换为
 * {@link org.springframework.jdbc.core.namedparam.SqlParameterSource} 时，
 * 使用 {@link Enum#ordinal()} 将枚举转换成整数。
 *
 * @author <a href="https://gitee.com/zhouxy108">ZhouXY</a>
 *
 * @see SqlParameterSource
 * @see BeanPropertySqlParameterSource
 * @see org.springframework.jdbc.core.namedparam.NamedParameterJdbcTemplate
 * @see Enum
 */
public class BeanPropertyParamSource extends BeanPropertySqlParameterSource {

   public BeanPropertyParamSource(Object object) {
       super(object);
   }

   @Override
   @Nullable
   public Object getValue(String paramName) throws IllegalArgumentException {
       Object value = super.getValue(paramName);
       if (value instanceof Enum) {
           return ((Enum<?>) value).ordinal();
       }
       return value;
   }
}
