/*
 * Copyright 2022-2023 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package xyz.zhouxy.plusone.jdbc;

import org.springframework.context.ApplicationContext;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.namedparam.NamedParameterJdbcTemplate;

import xyz.zhouxy.plusone.spring.SpringContextHolder;

/**
 * 全局单例，由 Spring 装配好的对象。
 * 可通过静态方法获取 Spring 容器中的 {@link JdbcTemplate} 和
 * {@link NamedParameterJdbcTemplate} 对象。
 *
 * @author <a href="https://gitee.com/zhouxy108">ZhouXY</a>
 * @see JdbcTemplate
 * @see NamedParameterJdbcTemplate
 */
public final class JdbcFactory {

    private static final ApplicationContext CONTEXT = SpringContextHolder.getContext();

    private JdbcFactory() {
        throw new IllegalStateException("Utility class");
    }

    public static JdbcTemplate getJdbcTemplate() {
        return CONTEXT.getBean(JdbcTemplate.class);
    }

    public static NamedParameterJdbcTemplate getNamedParameterJdbcTemplate() {
        return CONTEXT.getBean(NamedParameterJdbcTemplate.class);
    }
}
