/*
 * Copyright 2022-2023 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package xyz.zhouxy.plusone.jdbc;

import java.io.Serializable;
import java.util.Optional;

import javax.annotation.Nonnull;

import org.springframework.jdbc.core.namedparam.NamedParameterJdbcTemplate;
import org.springframework.jdbc.core.namedparam.SqlParameterSource;

import xyz.zhouxy.plusone.domain.AggregateRoot;
import xyz.zhouxy.plusone.domain.IRepository;

public abstract class JdbcRepositorySupport<T extends AggregateRoot<ID>, ID extends Serializable>
        extends JdbcEntityDaoSupport<T, ID>
        implements IRepository<T, ID> {

    protected JdbcRepositorySupport(@Nonnull NamedParameterJdbcTemplate namedParameterJdbcTemplate) {
        super(namedParameterJdbcTemplate);
    }

    protected abstract void doDelete(@Nonnull T entity);

    protected abstract Optional<T> doFindById(@Nonnull ID id);

    protected abstract T doInsert(@Nonnull T entity);

    protected abstract T doUpdate(@Nonnull T entity);

    @Override
    public final void delete(T entity) {
        if (entity == null) {
            throw new IllegalArgumentException("Cannot delete null.");
        }
        doDelete(entity);
    }

    @Override
    public final Optional<T> find(ID id) {
        if (id == null) {
            throw new IllegalArgumentException("Id cannot be null.");
        }
        return doFindById(id);
    }

    @Override
    public final T save(T entity) {
        if (entity == null) {
            throw new IllegalArgumentException("Cannot save null.");
        }
        return entity.getId().isPresent() ? doUpdate(entity) : doInsert(entity);
    }

    protected abstract SqlParameterSource generateParamSource(ID id, @Nonnull T entity);

    protected final SqlParameterSource generateParamSource(@Nonnull T entity) {
        return generateParamSource(entity.getId().orElseThrow(), entity);
    }
}
