/*
 * Copyright 2022-2023 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package xyz.zhouxy.plusone.jdbc.common;

import java.sql.ResultSet;
import java.sql.SQLException;

import org.springframework.jdbc.core.BeanPropertyRowMapper;
import org.springframework.jdbc.core.RowMapper;

public class SimpleResultMapper<T> implements ResultMapper<T> {

    private final RowMapper<T> rowMapper;

    public SimpleResultMapper(RowMapper<T> rowMapper) {
        this.rowMapper = rowMapper;
    }

    @Override
    public T map(ResultSet resultSet) throws SQLException {
        return rowMapper.mapRow(resultSet, 1);
    }

    @Override
    public T rowMapper(ResultSet resultSet, int rowNum) throws SQLException {
        return this.rowMapper.mapRow(resultSet, rowNum);
    }

    public static <T> SimpleResultMapper<T> of(Class<T> clazz) {
        return new SimpleResultMapper<>(new BeanPropertyRowMapper<>(clazz));
    }
}
