/*
 * Copyright 2022-2023 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package xyz.zhouxy.plusone.mail;

import org.springframework.boot.autoconfigure.condition.ConditionalOnClass;
import org.springframework.boot.context.properties.EnableConfigurationProperties;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.mail.javamail.JavaMailSender;

/**
 * 读取配置文件，实例化 {@link MailService} 对象后，放到 Spring 容器中。
 *
 * @author <a href="https://gitee.com/zhouxy108">ZhouXY</a>
 */
@Configuration
@EnableConfigurationProperties(PlusoneMailProperties.class)
@ConditionalOnClass(MailService.class)
public class PlusoneMailAutoConfiguration {

    @Bean
    MailService mailService(JavaMailSender mailSender, PlusoneMailProperties mailProperties) {
        MailMessageFactory mailMessageFactory = new MailMessageFactory(mailProperties);
        return new SimpleMailService(mailSender, mailMessageFactory);
    }
}
