/*
 * Copyright 2022-2023 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package xyz.zhouxy.plusone.redis;

import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.data.redis.core.ValueOperations;
import org.springframework.stereotype.Repository;

import java.util.concurrent.TimeUnit;

/**
 * 使用 Redis 存放临时字符串
 *
 * @author <a href="https://gitee.com/zhouxy108">ZhouXY</a>
 */
@Repository
public class RedisStrCacheDAO implements StrCacheDAO {

    private final StringRedisTemplate template;

    public RedisStrCacheDAO(StringRedisTemplate template) {
        this.template = template;
    }

    @Override
    public void setValue(String key, String value, long timeout, TimeUnit unit) {
        ValueOperations<String, String> ops = template.opsForValue();
        ops.set(key, value, timeout, unit);
    }

    @Override
    public String getValue(String key) {
        ValueOperations<String, String> ops = this.template.opsForValue();
        return ops.get(key);
    }

    @Override
    public String getValueAndDelete(String key) {
        ValueOperations<String, String> ops = this.template.opsForValue();
        String value = ops.get(key);
        template.delete(key);
        return value;
    }
}
