/*
 * Copyright 2022-2023 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package xyz.zhouxy.plusone.sms;

import java.util.Map;

import org.springframework.boot.context.properties.ConfigurationProperties;

/**
 * SMS 相关参数
 *
 * @author <a href="https://gitee.com/zhouxy108">ZhouXY</a>
 */
@ConfigurationProperties("plusone.sms")
public class SmsProperties {
    private String region;
    private SmsCredentialProperties credential;
    private SmsClientProperties client;
    private String appId;
    private Map<String, String> templates;

    public String getRegion() {
        return region;
    }

    public void setRegion(String region) {
        this.region = region;
    }

    public SmsCredentialProperties getCredential() {
        return credential;
    }

    public void setCredential(SmsCredentialProperties credential) {
        this.credential = credential;
    }

    public SmsClientProperties getClient() {
        return client;
    }

    public void setClient(SmsClientProperties client) {
        this.client = client;
    }

    public String getAppId() {
        return appId;
    }

    public void setAppId(String appId) {
        this.appId = appId;
    }

    public Map<String, String> getTemplates() {
        return templates;
    }

    public void setTemplates(Map<String, String> templates) {
        this.templates = templates;
    }

    public static class SmsCredentialProperties {
        private String secretId;
        private String secretKey;

        public String getSecretId() {
            return secretId;
        }

        public void setSecretId(String secretId) {
            this.secretId = secretId;
        }

        public String getSecretKey() {
            return secretKey;
        }

        public void setSecretKey(String secretKey) {
            this.secretKey = secretKey;
        }
    }

    public static class SmsClientProperties {
        private String signMethod;
        private SmsHttpProperties http;

        public String getSignMethod() {
            return signMethod;
        }

        public void setSignMethod(String signMethod) {
            this.signMethod = signMethod;
        }

        public SmsHttpProperties getHttp() {
            return http;
        }

        public void setHttp(SmsHttpProperties http) {
            this.http = http;
        }
    }

    public static class SmsHttpProperties {
        private SmsProxyProperties proxy;
        private String reqMethod;
        private Integer connTimeout;

        public SmsProxyProperties getProxy() {
            return proxy;
        }

        public void setProxy(SmsProxyProperties proxy) {
            this.proxy = proxy;
        }

        public String getReqMethod() {
            return reqMethod;
        }

        public void setReqMethod(String reqMethod) {
            this.reqMethod = reqMethod;
        }

        public Integer getConnTimeout() {
            return connTimeout;
        }

        public void setConnTimeout(Integer connTimeout) {
            this.connTimeout = connTimeout;
        }
    }

    public static class SmsProxyProperties {
        private String host;
        private Integer port;

        public String getHost() {
            return host;
        }

        public void setHost(String host) {
            this.host = host;
        }

        public Integer getPort() {
            return port;
        }

        public void setPort(Integer port) {
            this.port = port;
        }
    }

}
