/*
 * Copyright 2022-2023 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package xyz.zhouxy.plusone.validator;

import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;
import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;

import org.aspectj.lang.annotation.Aspect;
import org.aspectj.lang.annotation.Before;
import org.springframework.context.ApplicationContext;
import org.springframework.stereotype.Component;

@Aspect
@Component
class ValidateDtosConfig {

    final Map<Class<?>, BaseValidator<?>> validatorMap = new ConcurrentHashMap<>();

    ValidateDtosConfig(ApplicationContext context) {
        Map<String, Object> beans = context.getBeansWithAnnotation(DtoValidator.class);
        for (var validator : beans.values()) {
            Class<?> targetClass = validator.getClass().getAnnotation(DtoValidator.class).value();
            this.validatorMap.put(targetClass, (BaseValidator<?>) validator);
        }
    }

    @Before("@annotation(ValidateDto) && args(dto)")
    @SuppressWarnings("unchecked")
    public <T> void doValidateDto(T dto) {
        BaseValidator<T> validator = (BaseValidator<T>) this.validatorMap.get(dto.getClass());
        if (validator != null) {
            validator.validate(dto);
        }
    }
}

@Target(ElementType.METHOD)
@Retention(RetentionPolicy.RUNTIME)
public @interface ValidateDto {
}
