/*
 * Copyright 2022-2023 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package xyz.zhouxy.plusone.validatortest;

import java.util.regex.Pattern;

import org.junit.jupiter.api.Test;

import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.NoArgsConstructor;
import xyz.zhouxy.plusone.commons.constant.PatternConsts;
import xyz.zhouxy.plusone.validator.BaseValidator;

class BaseValidatorTest {

    @Test
    void testValid() {
        LoginCommand loginCommand = new LoginCommand("13169053215@qq.com", "A1qZ6c-cQ78=^(", false);
        LoginCommandValidator.INSTANCE.validate(loginCommand);
        System.err.println(loginCommand);
    }
}

@Data
@NoArgsConstructor
@AllArgsConstructor
class LoginCommand {
    private String account;
    private String pwd;
    private boolean rememberMe;
}

class LoginCommandValidator extends BaseValidator<LoginCommand> {

    public static final LoginCommandValidator INSTANCE = new LoginCommandValidator();

    private LoginCommandValidator() {
        ruleForString(LoginCommand::getAccount)
                .notNull("邮箱地址不能为空")
                .matchesOr(new Pattern[] { PatternConsts.EMAIL, PatternConsts.MOBILE_PHONE },
                        value -> new RuntimeException('"' + value + "\" 不是邮箱地址或手机号"));
        ruleForString(LoginCommand::getPwd)
                .notNull("密码不能为空")
                .notEmpty("密码不能为空")
                .matches(PatternConsts.PASSWORD, "密码格式错误");
    }
}
