/*
 * Copyright 2022-2023 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package xyz.zhouxy.plusone.system.application.controller;

import static xyz.zhouxy.plusone.system.constant.AuthLogic.adminAuthLogic;

import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import xyz.zhouxy.plusone.commons.util.RestfulResult;
import xyz.zhouxy.plusone.system.application.service.AccountContextService;
import xyz.zhouxy.plusone.system.application.service.command.ChangePasswordCommand;
import xyz.zhouxy.plusone.system.application.service.command.ChangePasswordWithoutLoginCommand;

/**
 * 账号查询本身相关信息
 *
 * @author <a href="https://gitee.com/zhouxy108">ZhouXY</a>
 */
@RestController
@RequestMapping("account")
public class AccountContextController {

    private final AccountContextService service;

    public AccountContextController(AccountContextService service) {
        this.service = service;
    }

    @GetMapping("info")
    public RestfulResult getAccountInfo() {
        adminAuthLogic.checkLogin();
        var result = service.getAccountInfo();
        return RestfulResult.success("查询成功", result);
    }

    @GetMapping("logout")
    public RestfulResult logout() {
        service.logout();
        return RestfulResult.success("注销成功");
    }

    @GetMapping("menus")
    public RestfulResult getMenuTree() {
        adminAuthLogic.checkLogin();
        var result = service.getMenuTree();
        return RestfulResult.success("查询成功", result);
    }

    @PostMapping("changePassword")
    public RestfulResult changePassword(ChangePasswordCommand command) {
        service.changePassword(command);
        return RestfulResult.success("修改成功，请重新登录。");
    }

    @PostMapping("changePasswordWithoutLogin")
    public RestfulResult changePasswordWithoutLogin(ChangePasswordWithoutLoginCommand command) {
        service.changePasswordWithoutLogin(command);
        return RestfulResult.success("修改成功，请重新登录。");
    }
}
