/*
 * Copyright 2022-2023 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package xyz.zhouxy.plusone.system.application.controller;

import static xyz.zhouxy.plusone.commons.util.RestfulResult.success;

import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import xyz.zhouxy.plusone.system.application.service.AdminLoginService;
import xyz.zhouxy.plusone.system.application.service.command.LoginByOtpCommand;
import xyz.zhouxy.plusone.system.application.service.command.LoginByPasswordCommand;
import xyz.zhouxy.plusone.commons.util.RestfulResult;

/**
 * Admin 账号登录
 *
 * @author <a href="https://gitee.com/zhouxy108">ZhouXY</a>
 */
@RestController
@RequestMapping("login")
public class AdminLoginController {

    private final AdminLoginService service;

    public AdminLoginController(AdminLoginService service) {
        this.service = service;
    }

    @PostMapping("byPassword")
    public RestfulResult loginByPassword(@RequestBody LoginByPasswordCommand command) {
        var loginInfo = service.loginByPassword(command);
        return success("登录成功", loginInfo);
    }

    @PostMapping("byOtp")
    public RestfulResult loginByOtp(@RequestBody LoginByOtpCommand command) {
        var loginInfo = service.loginByOtp(command);
        return success("登录成功", loginInfo);
    }

    @GetMapping("sendOtp")
    public RestfulResult sendOtp(@RequestParam String principal) {
        service.sendOtp(principal);
        return success("发送成功");
    }
}
