/*
 * Copyright 2022-2023 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package xyz.zhouxy.plusone.system.application.controller;

import static xyz.zhouxy.plusone.commons.util.RestfulResult.success;

import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import xyz.zhouxy.plusone.system.application.service.RegisterAccountService;
import xyz.zhouxy.plusone.system.application.service.command.RegisterAccountCommand;
import xyz.zhouxy.plusone.commons.util.RestfulResult;

/**
 * 注册账号服务
 *
 * @author <a href="https://gitee.com/zhouxy108">ZhouXY</a>
 */
@RestController
@RequestMapping("register")
public class RegisterAccountController {

    private final RegisterAccountService service;

    public RegisterAccountController(RegisterAccountService service) {
        this.service = service;
    }

    @PostMapping
    public RestfulResult registerAccount(@RequestBody RegisterAccountCommand command) {
        service.registerAccount(command);
        return success("注册成功");
    }

    @GetMapping("sendCode")
    public RestfulResult sendCode(@RequestParam String principal) {
        service.sendCode(principal);
        return success("发送成功");
    }
}
