/*
 * Copyright 2022-2023 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package xyz.zhouxy.plusone.system.application.exception;

import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.ResponseStatus;

import xyz.zhouxy.plusone.exception.BizException;

@ResponseStatus(HttpStatus.BAD_REQUEST)
public class AccountLoginException extends BizException {
    @java.io.Serial
    private static final long serialVersionUID = -3040996790739138556L;

    private static final int DEFAULT_ERR_CODE = 4030000;

    private AccountLoginException() {
        super(DEFAULT_ERR_CODE, "用户登录异常");
    }

    private AccountLoginException(int code, String message) {
        super(code, message);
    }

    public static AccountLoginException accountNotExistException() {
        return accountNotExistException("用户账户不存在");
    }

    public static AccountLoginException accountNotExistException(String msg) {
        return new AccountLoginException(4030101, msg);
    }

    public static AccountLoginException otpErrorException() {
        return otpErrorException("验证码错误");
    }

    public static AccountLoginException otpErrorException(String msg) {
        return new AccountLoginException(4030501, msg);
    }

    public static AccountLoginException otpNotExistsException() {
        return otpNotExistsException("验证码不存在或已过期");
    }

    public static AccountLoginException otpNotExistsException(String msg) {
        return new AccountLoginException(4030502, msg);
    }

    public static AccountLoginException passwordErrorException() {
        return passwordErrorException("用户密码错误");
    }

    public static AccountLoginException passwordErrorException(String msg) {
        return new AccountLoginException(4030200, msg);
    }
}
