/*
 * Copyright 2022-2023 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package xyz.zhouxy.plusone.system.application.query;

import java.util.List;

import org.apache.ibatis.jdbc.SQL;
import org.springframework.jdbc.core.BeanPropertyRowMapper;
import org.springframework.jdbc.core.namedparam.BeanPropertySqlParameterSource;
import org.springframework.jdbc.core.namedparam.NamedParameterJdbcTemplate;
import org.springframework.stereotype.Component;

import xyz.zhouxy.plusone.system.application.query.params.DictQueryParams;
import xyz.zhouxy.plusone.system.application.query.result.DictOverview;

/**
 * 数据字典查询器
 *
 * @author <a href="https://gitee.com/zhouxy108">ZhouXY</a>
 */
@Component
public class DictQueries {

    private final NamedParameterJdbcTemplate jdbcTemplate;

    public DictQueries(NamedParameterJdbcTemplate jdbcTemplate) {
        this.jdbcTemplate = jdbcTemplate;
    }

    public List<DictOverview> queryDictOverviewList(DictQueryParams queryParams) {
        String sql = new SQL() {
            {
                SELECT("id", "dict_type", "dict_label",
                        "created_by", "create_time", "updated_by", "update_time", "count");
                FROM("view_sys_dict_overview");
                if (queryParams.getDictType() != null) {
                    WHERE("dict_type LIKE '%:dictType%'");
                }
                if (queryParams.getDictLabel() != null) {
                    WHERE("dict_label LIKE '%:dictLabel%'");
                }
            }
        }.toString();
        return this.jdbcTemplate
                .query(sql, new BeanPropertySqlParameterSource(queryParams),
                        new BeanPropertyRowMapper<>(DictOverview.class));
    }
}
