/*
 * Copyright 2022-2023 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package xyz.zhouxy.plusone.system.application.query;

import java.util.List;

import org.springframework.jdbc.core.BeanPropertyRowMapper;
import org.springframework.jdbc.core.namedparam.BeanPropertySqlParameterSource;
import org.springframework.jdbc.core.namedparam.NamedParameterJdbcTemplate;
import org.springframework.stereotype.Repository;

import org.apache.ibatis.jdbc.SQL;
import xyz.zhouxy.plusone.system.application.query.params.RoleQueryParams;
import xyz.zhouxy.plusone.system.application.query.result.RoleOverview;

/**
 * 角色信息查询器
 *
 * @author <a href="https://gitee.com/zhouxy108">ZhouXY</a>
 */
@Repository
public class RoleQueries {

    private final NamedParameterJdbcTemplate jdbcTemplate;

    public RoleQueries(NamedParameterJdbcTemplate jdbcTemplate) {
        this.jdbcTemplate = jdbcTemplate;
    }

    /**
     * 查询 Role
     * <p>
     * <b> ！！！注意：此方法内存在字符串拼接，勿在循环内使用。</b>
     * </p>
     *
     * @param params 查询参数
     * @return 查询结果
     */
    public List<RoleOverview> query(RoleQueryParams params) {
        var sql = new SQL() {
            {
                SELECT("a.id AS id", "a.name AS name", "a.identifier AS identifier", "a.status AS status");
                FROM("sys_role AS a", "(" +
                        new SQL() {
                            {
                                SELECT("id");
                                FROM("sys_role");
                                if (null != params.getId()) {
                                    WHERE("id = :id");
                                }
                                if (null != params.getName()) {
                                    WHERE("name = :name");
                                }
                                if (null != params.getIdentifier()) {
                                    WHERE("identifier = :identifier");
                                }
                                if (null != params.getStatus()) {
                                    WHERE("status = :status");
                                }
                                if (null != params.getCreateTimeStart()) {
                                    WHERE("create_time >= :createTimeStart");
                                }
                                if (null != params.getCreateTimeEnd()) {
                                    WHERE("create_time < :createTimeEnd");
                                }
                                if (null != params.getUpdateTimeStart()) {
                                    WHERE("update_time >= :updateTimeStart");
                                }
                                if (null != params.getUpdateTimeEnd()) {
                                    WHERE("update_time < :updateTimeEnd");
                                }
                                LIMIT(params.getSize());
                                OFFSET(params.getOffset());
                            }
                        }.toString() + ") AS b");
                WHERE("a.id = b.id");
            }
        }.toString();
        return this.jdbcTemplate
                .query(sql, new BeanPropertySqlParameterSource(params),
                        new BeanPropertyRowMapper<>(RoleOverview.class));
    }
}
