/*
 * Copyright 2022-2023 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package xyz.zhouxy.plusone.system.application.query.params;

import java.time.LocalDate;

import lombok.Getter;
import lombok.Setter;
import lombok.ToString;
import xyz.zhouxy.plusone.commons.util.PagingAndSortingQueryParams;

/**
 * 账号信息查询参数
 *
 * @author <a href="https://gitee.com/zhouxy108">ZhouXY</a>
 */
@ToString
public class AccountQueryParams extends PagingAndSortingQueryParams {

    public AccountQueryParams() {
        super("id",
                "username",
                "email",
                "mobile_phone",
                "status",
                "nickname",
                "sex",
                "created_by",
                "create_time",
                "updated_by",
                "update_time");
    }

    // TODO【添加】 注解参数校验
    private @Getter @Setter Long id;
    private @Getter @Setter String username;
    private @Getter @Setter String email;
    private @Getter @Setter String mobilePhone;
    private @Getter @Setter Integer status;
    private @Getter @Setter String nickname;
    private @Getter @Setter Integer sex;
    private @Getter @Setter Long createdBy;
    private @Getter @Setter LocalDate createTimeStart;
    private @Getter LocalDate createTimeEnd;
    private @Getter @Setter Long updatedBy;
    private @Getter @Setter LocalDate updateTimeStart;
    private @Getter LocalDate updateTimeEnd;
    private @Getter @Setter Long roleId;

    public void setCreateTimeEnd(LocalDate createTimeEnd) {
        this.createTimeEnd = createTimeEnd.plusDays(1);
    }

    public void setUpdateTimeEnd(LocalDate updateTimeEnd) {
        this.updateTimeEnd = updateTimeEnd.plusDays(1);
    }
}
