/*
 * Copyright 2022-2023 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package xyz.zhouxy.plusone.system.application.service.command;

import java.util.Set;

import javax.validation.constraints.Email;
import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Pattern;

import org.hibernate.validator.constraints.URL;

import lombok.Data;
import xyz.zhouxy.plusone.commons.constant.RegexConsts;
import xyz.zhouxy.plusone.domain.ICommand;

/**
 * 创建账号命令
 *
 * @author <a href="https://gitee.com/zhouxy108">ZhouXY</a>
 */
@Data
public class CreateAccountCommand implements ICommand {

    @NotBlank
    @Pattern(regexp = RegexConsts.USERNAME, message = "用户名格式错误")
    String username;

    @Email(message = "邮箱地址格式错误")
    String email;

    @Pattern(regexp = RegexConsts.MOBILE_PHONE, message = "手机号格式错误")
    String mobilePhone;

    @NotBlank
    @Pattern(regexp = RegexConsts.PASSWORD, message = "密码不符合要求")
    String password;
    @NotBlank
    @Pattern(regexp = RegexConsts.PASSWORD, message = "密码不符合要求")
    String passwordConfirmation;

    @NotNull
    Integer status;

    Set<Long> roleRefs;

    @Pattern(regexp = RegexConsts.NICKNAME, message = "昵称格式错误")
    String nickname;

    @NotBlank
    @URL
    String avatar;

    Integer sex;
}
