/*
 * Copyright 2022-2023 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package xyz.zhouxy.plusone.system.application.service.command.validator;

import java.util.List;
import org.springframework.stereotype.Component;

import xyz.zhouxy.plusone.commons.constant.PatternConsts;
import xyz.zhouxy.plusone.system.application.service.command.LoginByPasswordCommand;
import xyz.zhouxy.plusone.validator.BaseValidator;
import xyz.zhouxy.plusone.validator.DtoValidator;

@Component
@DtoValidator(LoginByPasswordCommand.class)
public class LoginByPasswordCommandValidator extends BaseValidator<LoginByPasswordCommand> {
    public LoginByPasswordCommandValidator() {
        ruleForString(LoginByPasswordCommand::getPrincipal)
                .notNull("输入用户名、邮箱地址或手机号")
                .notEmpty("输入用户名、邮箱地址或手机号")
                .matchesOr(List.of(PatternConsts.USERNAME, PatternConsts.EMAIL, PatternConsts.MOBILE_PHONE),
                        "输入用户名、邮箱地址或手机号");
        ruleForString(LoginByPasswordCommand::getPassword)
                .notNull("密码不能为空")
                .notEmpty("密码不能为空")
                .matches(PatternConsts.PASSWORD, "密码格式不正确");
    }
}
