/*
 * Copyright 2022-2023 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package xyz.zhouxy.plusone.system.domain.event;

import lombok.Getter;
import lombok.NoArgsConstructor;
import lombok.Setter;
import lombok.ToString;
import xyz.zhouxy.plusone.domain.DomainEvent;
import xyz.zhouxy.plusone.system.domain.model.account.Account;
import xyz.zhouxy.plusone.system.domain.model.account.Email;
import xyz.zhouxy.plusone.system.domain.model.account.MobilePhone;
import xyz.zhouxy.plusone.system.domain.model.account.Username;

/**
 * 领域事件：账号用户名修改事件
 *
 * @author <a href="https://gitee.com/zhouxy108">ZhouXY</a>
 */
@Getter
@Setter
@NoArgsConstructor
@ToString(callSuper = true)
public class UsernameChanged extends DomainEvent {

    private Username username;
    private Email email;
    private MobilePhone mobilePhone;

    public UsernameChanged(Account account) {
        this.username = account.getUsername();
        this.email = account.getEmail().orElse(null);
        this.mobilePhone = account.getMobilePhone().orElse(null);
    }
}
