/*
 * Copyright 2022-2023 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package xyz.zhouxy.plusone.system.domain.model.account;

import lombok.Getter;
import xyz.zhouxy.plusone.commons.util.Enumeration;
import xyz.zhouxy.plusone.domain.IValueObject;

/**
 * 账号状态
 *
 * @author <a href="https://gitee.com/zhouxy108">ZhouXY</a>
 */
@Getter
public final class AccountStatus extends Enumeration<AccountStatus> implements IValueObject {

    private AccountStatus(int value, String name) {
        super(value, name);
    }

    public static final AccountStatus AVAILABLE = new AccountStatus(0, "账号正常");
    public static final AccountStatus LOCKED = new AccountStatus(1, "账号被锁定");

    private static final EnumerationValuesHolder<AccountStatus> ENUMERATION_VALUES = new EnumerationValuesHolder<>(
            AVAILABLE,
            LOCKED);

    public static AccountStatus of(int value) {
        return ENUMERATION_VALUES.get(value);
    }
}
