/*
 * Copyright 2022-2023 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package xyz.zhouxy.plusone.system.domain.model.account;

import java.util.Objects;
import java.util.regex.Pattern;

import cn.hutool.core.util.DesensitizedUtil;
import xyz.zhouxy.plusone.commons.constant.PatternConsts;

/**
 * 值对象：电子邮箱地址
 *
 * @author <a href="https://gitee.com/zhouxy108">ZhouXY</a>
 */
public class Email extends Principal {

    public static final Pattern REGEX = PatternConsts.EMAIL;

    private Email(String email) {
        super(REGEX);
        if (email == null) {
            throw new IllegalArgumentException("邮箱地址不能为空");
        }
        this.value = email;
        if (!isValid()) {
            throw new IllegalArgumentException("邮箱地址格式错误");
        }
    }

    public static Email of(String email) {
        return new Email(email);
    }

    public static Email ofNullable(String email) {
        return Objects.nonNull(email) ? new Email(email) : null;
    }

    /**
     * 脱敏后的数据
     */
    public String safeValue() {
        return DesensitizedUtil.email(this.value);
    }

    @Override
    public String toString() {
        return this.safeValue();
    }
}
