/*
 * Copyright 2022-2023 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package xyz.zhouxy.plusone.system.domain.model.account;

import java.util.Objects;
import java.util.regex.Pattern;

import cn.hutool.core.util.DesensitizedUtil;
import xyz.zhouxy.plusone.commons.constant.PatternConsts;

/**
 * 值对象：手机号码
 *
 * @author <a href="https://gitee.com/zhouxy108">ZhouXY</a>
 */
public class MobilePhone extends Principal {

    public static final Pattern REGEX = PatternConsts.MOBILE_PHONE;

    private MobilePhone(String mobilePhone) {
        super(REGEX);
        if (mobilePhone == null) {
            throw new IllegalArgumentException("手机号不能为空");
        }
        this.value = mobilePhone;
        if (!isValid()) {
            throw new IllegalArgumentException("手机号格式错误");
        }
    }

    public static MobilePhone of(String mobilePhone) {
        return new MobilePhone(mobilePhone);
    }

    public static MobilePhone ofNullable(String mobilePhone) {
        return Objects.nonNull(mobilePhone) ? new MobilePhone(mobilePhone) : null;
    }

    public String safeValue() {
        return DesensitizedUtil.mobilePhone(this.value);
    }

    @Override
    public String toString() {
        return this.safeValue();
    }
}
