/*
 * Copyright 2022-2023 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package xyz.zhouxy.plusone.system.domain.model.account;

import java.util.Objects;
import java.util.regex.Pattern;

import xyz.zhouxy.plusone.commons.constant.PatternConsts;
import xyz.zhouxy.plusone.domain.ValidatableStringRecord;

/**
 * 值对象：昵称
 *
 * @author <a href="https://gitee.com/zhouxy108">ZhouXY</a>
 */
public class Nickname extends ValidatableStringRecord {

    public static final Pattern REGEX = PatternConsts.NICKNAME;

    private Nickname(String value) {
        super(REGEX);
        if (value == null) {
            throw new IllegalArgumentException("昵称不能为空");
        }
        this.value = value;
        if (!isValid()) {
            throw new IllegalArgumentException("昵称格式错误");
        }
    }

    public static Nickname of(String nickname) {
        return new Nickname(nickname);
    }

    public static Nickname ofNullable(String nickname) {
        return Objects.nonNull(nickname) ? new Nickname(nickname) : null;
    }
}
