/*
 * Copyright 2022-2023 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package xyz.zhouxy.plusone.system.domain.model.account;

import javax.annotation.Nonnull;

import xyz.zhouxy.plusone.commons.util.Enumeration;
import xyz.zhouxy.plusone.domain.IValueObject;

/**
 * 值对象：性别
 *
 * @author <a href="https://gitee.com/zhouxy108">ZhouXY</a>
 */
public final class Sex extends Enumeration<Sex> implements IValueObject {
    @Nonnull
    public static final Sex UNSET = new Sex(0, "未设置");
    @Nonnull
    public static final Sex MALE = new Sex(1, "男性");
    @Nonnull
    public static final Sex FEMALE = new Sex(2, "女性");

    private Sex(int value, String name) {
        super(value, name);
    }

    private static EnumerationValuesHolder<Sex> values = new EnumerationValuesHolder<>(
            UNSET,
            MALE,
            FEMALE);

    public static Sex of(int value) {
        return values.get(value);
    }
}
