/*
 * Copyright 2022-2023 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package xyz.zhouxy.plusone.system.domain.model.account;

import java.util.regex.Pattern;

import xyz.zhouxy.plusone.commons.constant.PatternConsts;

/**
 * 值对象：用户名
 *
 * @author <a href="https://gitee.com/zhouxy108">ZhouXY</a>
 */
public class Username extends Principal {

    public static final Pattern REGEX = PatternConsts.USERNAME;

    private Username(String username) {
        super(REGEX);
        if (username == null) {
            throw new IllegalArgumentException("用户名不能为空");
        }
        this.value = username;
        if (!isValid()) {
            throw new IllegalArgumentException("用户名格式错误");
        }
    }

    public static Username of(String username) {
        return new Username(username);
    }
}
