/*
 * Copyright 2022-2023 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package xyz.zhouxy.plusone.system.domain.model.menu;

import java.util.Optional;

import com.fasterxml.jackson.annotation.JsonProperty;

import lombok.Getter;
import xyz.zhouxy.plusone.domain.Entity;
import xyz.zhouxy.plusone.domain.IWithLabel;

/**
 * 行为。
 * <p>
 * 一个 Menu 代表对应一个资源，Action 表示对该资源的行为，每个行为具有对应权限。
 * </p>
 *
 * @author <a href="https://gitee.com/zhouxy108">ZhouXY</a>
 *
 * @see Menu
 */
public class Action extends Entity<Long> implements IWithLabel {

    Long id;
    String resource;
    @Getter
    String identifier;
    @Getter
    String label;

    private Action(Long id, String resource, String identifier, String label) {
        this.id = id;
        this.resource = resource;
        this.identifier = identifier;
        this.label = label;
    }

    static Action of(Long id, String resource, String identifier, String label) {
        return new Action(id, resource, identifier, label);
    }

    static Action newInstance(String resource, String identifier, String label) {
        return new Action(null, resource, identifier, label);
    }

    @JsonProperty("value")
    public String value() {
        return resource + identifier;
    }

    @Override
    public Optional<Long> getId() {
        return Optional.ofNullable(id);
    }
}
