/*
 * Copyright 2022-2023 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package xyz.zhouxy.plusone.system.domain.model.menu;

import java.util.List;

import xyz.zhouxy.plusone.constant.EntityStatus;
import xyz.zhouxy.plusone.system.domain.model.menu.Menu.MenuType;

/**
 * 菜单构造器。生成新的 MenuList 或 MenuItem
 *
 * @author <a href="https://gitee.com/zhouxy108">ZhouXY</a>
 */
public class MenuConstructor {

    private MenuConstructor() {
        throw new IllegalStateException("Utility class");
    }

    public static Menu newMenuItem(
            long parentId,
            String path,
            String name,
            String title,
            String icon,
            boolean hidden,
            int orderNumber,
            EntityStatus status,
            String component,
            String resource,
            boolean cache,
            String remarks) {
        List<Action> actions = List.of(
                Action.newInstance(resource, "-query", "查询"),
                Action.newInstance(resource, "-details", "详情"),
                Action.newInstance(resource, "-add", "新增"),
                Action.newInstance(resource, "-update", "修改"),
                Action.newInstance(resource, "-delete", "删除"));
        return new Menu(MenuType.MENU_ITEM, null, parentId, name, path, title, icon, hidden, orderNumber, status,
                remarks, component, cache, resource, actions, 0L);
    }

    public static Menu newMenuList(
            long parentId,
            String path,
            String name,
            String title,
            String icon,
            boolean hidden,
            int orderNumber,
            EntityStatus status,
            String remarks) {
        return new Menu(MenuType.MENU_LIST, null, parentId, name, path, title, icon, hidden, orderNumber, status,
                remarks, null, null, null, null, 0L);
    }
}
