/*
 * Copyright 2022-2023 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package xyz.zhouxy.plusone.system.domain.model.permission;

import java.util.Optional;

import lombok.Getter;
import xyz.zhouxy.plusone.domain.Entity;
import xyz.zhouxy.plusone.domain.IWithLabel;
import xyz.zhouxy.plusone.domain.IWithVersion;

/**
 * 行为
 *
 * @author <a href="https://gitee.com/zhouxy108">ZhouXY</a>
 */
public class Action extends Entity<Long> implements IWithLabel, IWithVersion {

    Long id;
    String resource;
    @Getter String identifier;
    @Getter String label;
    @Getter long version;

    public Action(Long id, String resource, String identifier, String label, long version) {
        this.id = id;
        this.resource = resource;
        this.identifier = identifier;
        this.label = label;
        this.version = version;
    }

    static Action newInstance(String resource, String identifier, String label) {
        return new Action(null, resource, identifier, label, 0L);
    }

    static Action existingInstance(Long id, String resource, String action, String label, Long version) {
        return new Action(id, resource, action, label, version);
    }

    public String value() {
        return resource + identifier;
    }

    @Override
    public Optional<Long> getId() {
        return Optional.ofNullable(id);
    }
}
