/*
 * Copyright 2022-2023 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package xyz.zhouxy.plusone.system.domain.model.permission;

import java.util.ArrayList;
import java.util.List;
import java.util.Objects;
import java.util.Optional;

import lombok.Getter;
import xyz.zhouxy.plusone.domain.AggregateRoot;
import xyz.zhouxy.plusone.domain.IWithVersion;

/**
 * 权限
 *
 * @author <a href="https://gitee.com/zhouxy108">ZhouXY</a>
 */
public class Permission extends AggregateRoot<Long> implements IWithVersion {

    private Long id;
    private @Getter String resource;

    private List<Action> actions = new ArrayList<>(8);

    private @Getter long version;

    public Permission addAction(String action, String label) {
        return addAction(Action.newInstance(resource, action, label));
    }

    public void removeAction(Long actionId) {
        this.actions.removeIf(action -> Objects.equals(actionId, action.getId().orElseThrow()));
    }

    public void removeAction(String identifier) {
        this.actions.removeIf(action -> Objects.equals(identifier, action.identifier));
    }

    // ==================== 实例化 ====================

    public static Permission newInstance(String resource) {
        return new Permission(
                null, resource,
                List.of(Action.newInstance(resource, ":add", "添加"),
                        Action.newInstance(resource, ":delete", "删除"),
                        Action.newInstance(resource, ":update", "更改"),
                        Action.newInstance(resource, ":query", "查询"),
                        Action.newInstance(resource, ":details", "详情")),
                0);
    }

    Permission(Long id, String resource, List<Action> actions, long version) {
        this.id = id;
        this.resource = resource;
        this.actions.addAll(actions);
        this.version = version;
    }

    // ==================== private ====================
    private Permission addAction(Action action) {
        this.actions.add(action);
        return this;
    }

    // ==================== getter ====================
    @Override
    public Optional<Long> getId() {
        return Optional.ofNullable(id);
    }
}
