/*
 * Copyright 2022-2023 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package xyz.zhouxy.plusone.system.domain.service;

import java.util.Collection;
import java.util.HashSet;
import java.util.Set;
import java.util.stream.Collectors;

import org.springframework.stereotype.Service;

import xyz.zhouxy.plusone.system.domain.model.menu.Menu;
import xyz.zhouxy.plusone.system.domain.model.menu.MenuRepository;
import xyz.zhouxy.plusone.system.domain.model.role.MenuRef;
import xyz.zhouxy.plusone.system.domain.model.role.Role;
import xyz.zhouxy.plusone.system.domain.model.role.RoleRepository;

/**
 * 领域服务：菜单服务
 *
 * @author <a href="https://gitee.com/zhouxy108">ZhouXY</a>
 */
@Service
public class MenuService {

    private final RoleRepository roleRepository;
    private final MenuRepository menuRepository;

    MenuService(RoleRepository roleRepository, MenuRepository menuRepository) {
        this.roleRepository = roleRepository;
        this.menuRepository = menuRepository;
    }

    /**
     * 根据账号 id 查询菜单列表（不形成树结构）
     * @param accountId
     * @return
     */
    public Collection<Menu> queryAllMenuListByAccountId(Long accountId) {
        Collection<Role> roles = roleRepository.findByAccountId(accountId);
        Set<MenuRef> menuRefs = new HashSet<>();
        roles.forEach(role -> menuRefs.addAll(role.getMenus()));
        return menuRepository.findByIdIn(menuRefs.stream().map(MenuRef::menuId).collect(Collectors.toSet()));
    }

}
