/*
 * Copyright 2022-2023 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package xyz.zhouxy.plusone.system.domain.model.account;

import java.util.Set;
import java.util.stream.Collectors;

import javax.annotation.Nonnull;

import org.springframework.jdbc.core.namedparam.MapSqlParameterSource;
import org.springframework.jdbc.core.namedparam.NamedParameterJdbcTemplate;

import xyz.zhouxy.plusone.jdbc.PlusoneJdbcDaoSupport;

class AccountRoleRefDAO extends PlusoneJdbcDaoSupport {

    AccountRoleRefDAO(@Nonnull NamedParameterJdbcTemplate jdbc) {
        super(jdbc);
    }

    Set<Long> selectRoleIdsByAccountId(Long accountId) {
        return queryForStream("""
                SELECT r.id FROM sys_role r RIGHT JOIN sys_account_role ar ON r.id = ar.role_id
                WHERE r.deleted = 0 AND ar.account_id = :accountId;
                """,
                "accountId", accountId,
                Long.TYPE)
                .collect(Collectors.toSet());
    }

    void clearAccountRoleRefs(Account entity) {
        update("DELETE FROM sys_account_role WHERE account_id = :accountId", "accountId", entity.getId().orElseThrow());
    }

    void insertAccountRoleRefs(Long accountId, Set<Long> roleRefs) {
        long i = batchUpdate(
                "INSERT INTO sys_account_role (account_id, role_id) VALUES (:accountId, :roleId)",
                roleRefs,
                (Long roleId) -> new MapSqlParameterSource()
                        .addValue("accountId", accountId)
                        .addValue("roleId", roleId));
        assertResultEquals(i, roleRefs.size());
    }

    void saveAccountRoleRefs(Account entity) {
        Long accountId = entity.getId().orElseThrow();
        Set<Long> roleRefs = entity.getRoleIds();
        clearAccountRoleRefs(entity);
        insertAccountRoleRefs(accountId, roleRefs);
    }
}
