/*
 * Copyright 2022-2023 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package xyz.zhouxy.plusone.system.domain.model.role;

import java.util.Set;
import java.util.stream.Collectors;

import javax.annotation.Nonnull;

import org.springframework.jdbc.core.namedparam.MapSqlParameterSource;
import org.springframework.jdbc.core.namedparam.NamedParameterJdbcTemplate;

import xyz.zhouxy.plusone.jdbc.PlusoneJdbcDaoSupport;

class RoleMenuRefDAO extends PlusoneJdbcDaoSupport {

    public RoleMenuRefDAO(@Nonnull NamedParameterJdbcTemplate jdbc) {
        super(jdbc);
    }

    Set<MenuRef> selectMenuRefsByRoleId(long roleId) {
        return queryForStream("SELECT menu_id FROM sys_role_menu WHERE role_id = :roleId",
                "roleId", roleId,
                Long.TYPE)
                .map(MenuRef::of)
                .collect(Collectors.toSet());
    }

    void clearRoleMenuRefs(Role entity) {
        update("DELETE FROM sys_role_menu WHERE role_id = :roleId", "roleId", entity.getId().orElseThrow());
    }

    void saveRoleMenuRefs(Long roleId, Role entity) {
        long i = batchUpdate(
                "INSERT INTO sys_role_menu(role_id, menu_id) VALUES (:roleId, :menuId)",
                entity.getMenus(),
                menuRef -> new MapSqlParameterSource()
                        .addValue("roleId", roleId)
                        .addValue("menuId", menuRef.menuId()));
        assertResultEquals(i, entity.getMenus().size());
    }
}
