/*
 * Copyright 2022-2023 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package xyz.zhouxy.plusone.system.domain.model.role;

import java.util.Set;
import java.util.stream.Collectors;

import javax.annotation.Nonnull;

import org.springframework.jdbc.core.namedparam.MapSqlParameterSource;
import org.springframework.jdbc.core.namedparam.NamedParameterJdbcTemplate;

import xyz.zhouxy.plusone.jdbc.PlusoneJdbcDaoSupport;

class RolePermissionRefDAO extends PlusoneJdbcDaoSupport {

    protected RolePermissionRefDAO(@Nonnull NamedParameterJdbcTemplate jdbc) {
        super(jdbc);
    }

    Set<ActionRef> selectPermissionRefsByRoleId(long roleId) {
        return queryForStream("SELECT permission_id FROM sys_role_permission WHERE role_id = :roleId",
                "roleId", roleId,
                Long.TYPE)
                .map(ActionRef::of)
                .collect(Collectors.toSet());
    }

    void clearRolePermissionRefs(Role entity) {
        update("DELETE FROM sys_role_permission WHERE role_id = :roleId",
                "roleId", entity.getId().orElseThrow());
    }

    void saveRolePermissionRefs(Long roleId, Role entity) {
        long i = batchUpdate(
                "INSERT INTO sys_role_permission(role_id, permission_id) VALUES (:roleId, :permissionId)",
                entity.getPermissions(),
                actionRef -> new MapSqlParameterSource()
                        .addValue("roleId", roleId)
                        .addValue("permissionId", actionRef.actionId()));
        assertResultEquals(i, entity.getMenus().size());
    }
}
